@@ -8,6 +8,7 @@ Copyright (C) 2010 Nick Leppänen Larsson <frals@frals.se>
 @license: GNU GPLv2, see COPYING file.
 """
 import os
+import logging
 
 import osso
 
@@ -23,6 +24,7 @@ CONNMODE_FORCESWITCH = 3
 class fMMS_config:
 
 	def __init__(self):
+		log = logging.getLogger('fmms.%s' % __name__)
 		self._fmmsdir = "/apps/fmms/"
 		self.client = gconf.client_get_default()
 		self.client.add_dir(self._fmmsdir, gconf.CLIENT_PRELOAD_NONE)
@@ -34,6 +36,9 @@ class fMMS_config:
 		if apn != "z_fMMS-APN":
 			settings = self.get_apn_settings()
 			advsettings = self.get_advanced_apn_settings()
+			log.info("Importing old settings from: %s" % apn)
+			log.info("APN settings: %s" % settings)
+			log.info("Advanced settings: %s" % advsettings)
 			apn = self.create_new_apn()
 			self.set_apn(apn)
 			self.set_apn_settings(settings)
@@ -209,58 +214,27 @@ class fMMS_config:
 			return passwd
 		else:
 			return ""
-			
-	def get_gprs_apns(self):
-		# get all IAP's
-		dirs = self.client.all_dirs('/system/osso/connectivity/IAP')
-		apnlist = []
-		for subdir in dirs:
-			# get all sub entries.. this might be costy?
-			all_entries = self.client.all_entries(subdir)
-			# this is a big loop as well, possible to make it easier?
-			# make this faster
-			for entry in all_entries:
-				(path, sep, shortname) = entry.key.rpartition('/')
-				# this SHOULD always be a int
-				if shortname == 'type' and entry.value.type == gconf.VALUE_STRING and entry.value.get_string() == "GPRS":	
-					# split it so we can get the id
-					#(spath, sep, apnid) = path.rpartition('/')
-					apname = self.client.get_string(path + '/name')
-					apnlist.append(apname)
-		
-		return apnlist
-	
-	""" get the gconf alias for the name, be it the real name or
-	an arbitrary string """
-	def get_apnid_from_name(self, apnname):
-		# get all IAP's
-		dirs = self.client.all_dirs('/system/osso/connectivity/IAP')
-		
-		for subdir in dirs:
-			# get all sub entries.. this might be costy?
-			all_entries = self.client.all_entries(subdir)
-			# this is a big loop as well, possible to make it easier?
-			for entry in all_entries:
-				(path, sep, shortname) = entry.key.rpartition('/')
-				
-				# this SHOULD always be a string
-				if shortname == 'name':				
-					if entry.value.type == gconf.VALUE_STRING:
-						_value = entry.value.get_string()
-					if _value == apnname:
-						# split it so we can get the id
-						(spath, sep, apnid) = path.rpartition('/')		
-						return apnid		
-		
-		return None
 	
 	def set_apn_settings(self, settings):
 		apn = self.get_apn()
+		if not settings:
+			settings = {}
+			settings['apn'] = ""
+			settings['user'] = ""
+			settings['pass'] = ""
+			settings['proxy'] = ""
+			settings['proxyport'] = "0"
+			settings['mmsc'] = ""
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_accesspointname', settings['apn'])
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_username', settings['user'])
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_password', settings['pass'])
-		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http', settings['proxy'])
-		self.client.set_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port', int(settings['proxyport']))
+		
+		if not settings['proxy'] or settings['proxy'] == "":
+			self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/proxytype', "NONE")	
+		else:
+			self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http', settings['proxy'])
+			self.client.set_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port', int(settings['proxyport']))
+		
 		self.set_mmsc(settings['mmsc'])
 		
 	def get_apn_settings(self):
@@ -269,14 +243,21 @@ class fMMS_config:
 		settings['apn'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/gprs_accesspointname')
 		settings['user'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/gprs_username')
 		settings['pass'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/gprs_password')
-		settings['proxy'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http')
-		settings['proxyport'] = self.client.get_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port')
+		proxytype = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/proxytype')
+		if proxytype != "NONE":
+			settings['proxy'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http')
+			settings['proxyport'] = self.client.get_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port')
 		settings['mmsc'] = self.get_mmsc()
 		
 		return settings
 		
 	def set_advanced_apn_settings(self, settings):
 		apn = self.get_apn()
+		if not settings:
+			settings = {}
+			settings['pdns'] = "0.0.0.0"
+			settings['sdns'] = "0.0.0.0"
+			settings['ip'] = "0.0.0.0"
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_dns1', settings['pdns'])
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_dns2', settings['sdns'])
 		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_address', settings['ip'])
